@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package Text::Treesitter 0.01;
+package Text::Treesitter 0.02;
 
 use v5.14;
 use warnings;
@@ -43,6 +43,18 @@ L<Text::Treesitter::Parser> - parse some input text according to a F<tree-sitter
 
 =item *
 
+L<Text::Treesitter::Query> - represents a set of F<tree-sitter> query patterns
+
+=item *
+
+L<Text::Treesitter::QueryCursor> - stores the result of a F<tree-sitter> node query
+
+=item *
+
+L<Text::Treesitter::QueryMatch> - stores the result of a F<tree-sitter> query pattern match
+
+=item *
+
 L<Text::Treesitter::Tree> - holds the result of a F<tree-sitter> parse operation
 
 =back
@@ -54,7 +66,6 @@ L<Text::Treesitter::Tree> - holds the result of a F<tree-sitter> parse operation
 The following C library functions are currently unhandled:
 
    the entire TSTreeCursor API
-   the entire TSQuery API
 
 =cut
 
